package com.ruoyi.sip.controller;

import java.util.List;

import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.sip.domain.DeliveryList;
import com.ruoyi.sip.service.IDeliveryListService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 发货清单Controller
 *
 * @author ruoyi
 * @date 2025-04-11
 */
@Controller
@RequestMapping("/sip/list")
public class DeliveryListController extends BaseController {
    private String prefix = "sip/list";

    @Autowired
    private IDeliveryListService deliveryListService;

    @RequiresPermissions("sip:list:view")
    @GetMapping()
    public String list() {
        return prefix + "/list";
    }

    /**
     * 查询发货清单列表
     */
    @RequiresPermissions("sip:list:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(DeliveryList deliveryList) {
        startPage();
        List<DeliveryList> list = deliveryListService.selectDeliveryListList(deliveryList);
        return getDataTable(list);
    }

    /**
     * 导入数据
     */

    @PostMapping("/importData")
    @ResponseBody
    public AjaxResult importData(MultipartFile file, Long deliveryId) throws Exception
    {
        ExcelUtil<DeliveryList> util = new ExcelUtil<DeliveryList>(DeliveryList.class);
        List<DeliveryList> deliveryList = util.importExcel(file.getInputStream());

        deliveryListService.importData(deliveryList, deliveryId);
        return AjaxResult.success("导入成功");
    }

    /**
     * 导出发货清单列表
     */
    @RequiresPermissions("sip:list:export")
    @Log(title = "发货清单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(DeliveryList deliveryList) {
        List<DeliveryList> list = deliveryListService.selectDeliveryListList(deliveryList);
        ExcelUtil<DeliveryList> util = new ExcelUtil<DeliveryList>(DeliveryList.class);
        return util.exportExcel(list, "发货清单数据");
    }

    /**
     * 新增发货清单
     */
    @RequiresPermissions("sip:list:add")
    @GetMapping("/add")
    public String add() {
        return prefix + "/add";
    }

    /**
     * 新增保存发货清单
     */
    @RequiresPermissions("sip:list:add")
    @Log(title = "发货清单", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(DeliveryList deliveryList) {
        return toAjax(deliveryListService.insertDeliveryList(deliveryList));
    }

    /**
     * 修改发货清单
     */
    @RequiresPermissions("sip:list:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap) {
        DeliveryList deliveryList = deliveryListService.selectDeliveryListById(id);
        mmap.put("deliveryList", deliveryList);
        return prefix + "/edit";
    }

    /**
     * 修改保存发货清单
     */
    @RequiresPermissions("sip:list:edit")
    @Log(title = "发货清单", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(DeliveryList deliveryList) {
        return toAjax(deliveryListService.updateDeliveryList(deliveryList));
    }

    /**
     * 删除发货清单
     */
    @RequiresPermissions("sip:list:remove")
    @Log(title = "发货清单", businessType = BusinessType.DELETE)
    @PostMapping("/remove")
    @ResponseBody
    public AjaxResult remove(String ids) {
        return toAjax(deliveryListService.deleteDeliveryListByIds(ids));
    }
}
