package com.ruoyi.sip.controller;

import java.util.List;

import com.ruoyi.sip.domain.OrderList;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.sip.domain.OrderInfo;
import com.ruoyi.sip.service.IOrderInfoService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 合同档案Controller
 * 
 * @author mula
 * @date 2025-04-11
 */
@Controller
@RequestMapping("/manage/order")
public class OrderInfoController extends BaseController
{
    private String prefix = "manage/order";

    @Autowired
    private IOrderInfoService orderInfoService;

    @RequiresPermissions("manage:order:view")
    @GetMapping()
    public String order()
    {
        return prefix + "/order";
    }

    /**
     * 查询合同档案列表
     */
    @RequiresPermissions("manage:order:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(OrderInfo orderInfo)
    {
        startPage();
        List<OrderInfo> list = orderInfoService.selectOrderInfoList(orderInfo);
        return getDataTable(list);
    }

    /**
     * 导出合同档案列表
     */
    @RequiresPermissions("manage:order:export")
    @Log(title = "合同档案", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(OrderInfo orderInfo)
    {
        List<OrderInfo> list = orderInfoService.selectOrderInfoList(orderInfo);
        ExcelUtil<OrderInfo> util = new ExcelUtil<OrderInfo>(OrderInfo.class);
        return util.exportExcel(list, "合同档案数据");
    }

    /**
     * 新增合同档案
     */
    @RequiresPermissions("manage:order:add")
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存合同档案
     */
    @RequiresPermissions("manage:order:add")
    @Log(title = "合同档案", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(OrderInfo orderInfo)
    {
        return toAjax(orderInfoService.insertOrderInfo(orderInfo));
    }

    /**
     * 修改合同档案
     */
    @RequiresPermissions("manage:order:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        OrderInfo orderInfo = orderInfoService.selectOrderInfoById(id);
        mmap.put("orderInfo", orderInfo);
        return prefix + "/edit";
    }

    /**
     * 修改保存合同档案
     */
    @RequiresPermissions("manage:order:edit")
    @Log(title = "合同档案", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(OrderInfo orderInfo)
    {
        return toAjax(orderInfoService.updateOrderInfo(orderInfo));
    }
    /**
     * 删除合同档案
     */
    @RequiresPermissions("manage:order:remove")
    @Log(title = "合同档案", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(orderInfoService.deleteOrderInfoByIds(ids));
    }
}
