package com.ruoyi.sip.service.impl;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.sip.domain.OrderList;
import com.ruoyi.sip.domain.ProductInfo;
import com.ruoyi.sip.mapper.OrderInfoMapper;
import com.ruoyi.sip.mapper.ProductInfoMapper;
import org.springframework.stereotype.Service;
import com.ruoyi.sip.mapper.DeliveryListMapper;
import com.ruoyi.sip.domain.DeliveryList;
import com.ruoyi.sip.service.IDeliveryListService;
import com.ruoyi.common.core.text.Convert;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;

/**
 * 发货清单Service业务层处理
 *
 * @author ruoyi
 * @date 2025-04-11
 */
@Service
@Transactional(rollbackFor = Exception.class)
public class DeliveryListServiceImpl implements IDeliveryListService {
    @Resource
    private DeliveryListMapper deliveryListMapper;

    @Resource
    private ProductInfoMapper productInfoMapper;

    @Resource
    private OrderInfoMapper infoMapper;

    /**
     * 查询发货清单
     *
     * @param id 发货清单主键
     * @return 发货清单
     */
    @Override
    public DeliveryList selectDeliveryListById(Long id) {
        return deliveryListMapper.selectDeliveryListById(id);
    }

    /**
     * 查询发货清单列表
     *
     * @param deliveryList 发货清单
     * @return 发货清单
     */
    @Override
    public List<DeliveryList> selectDeliveryListList(DeliveryList deliveryList) {
        return deliveryListMapper.selectDeliveryListList(deliveryList);
    }

    /**
     * 新增发货清单
     *
     * @param deliveryList 发货清单
     * @return 结果
     */
    @Override
    public int insertDeliveryList(DeliveryList deliveryList) {
        return deliveryListMapper.insertDeliveryList(deliveryList);
    }

    /**
     * 修改发货清单
     *
     * @param deliveryList 发货清单
     * @return 结果
     */
    @Override
    public int updateDeliveryList(DeliveryList deliveryList) {
        return deliveryListMapper.updateDeliveryList(deliveryList);
    }

    /**
     * 批量删除发货清单
     *
     * @param ids 需要删除的发货清单主键
     * @return 结果
     */
    @Override
    public int deleteDeliveryListByIds(String ids) {
        return deliveryListMapper.deleteDeliveryListByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除发货清单信息
     *
     * @param id 发货清单主键
     * @return 结果
     */
    @Override
    public int deleteDeliveryListById(Long id) {
        return deliveryListMapper.deleteDeliveryListById(id);
    }

    @Override
    public void importData(List<DeliveryList> deliveryList, Long deliveryId) {
        List<String> productCodeList = deliveryList.stream().map(DeliveryList::getProductCode).collect(Collectors.toList());
        if (productCodeList.isEmpty()) {
            throw new ServiceException("产品编码为空");
        }
        List<OrderList> orderLists = infoMapper.listOrderListByDeliveryId(deliveryId);
        if (orderLists.isEmpty()) {
            throw new ServiceException("发货单中没有产品");
        }
        List<String> existsProductCodeList = orderLists.stream().map(OrderList::getProductCode).collect(Collectors.toList());
        List<String> notExistsProductCodeList = productCodeList.stream().filter(productCode -> !existsProductCodeList.contains(productCode)).collect(Collectors.toList());
        if (!notExistsProductCodeList.isEmpty()) {
            throw new ServiceException(StringUtils.format("产品编码为[{}]的产品在发货单中未找到,请确认后重试;", String.join(",", notExistsProductCodeList)));
        }

        for (DeliveryList list : deliveryList) {
            list.setDeliveryId(deliveryId);
        }

        deliveryListMapper.insertBatch(deliveryList);
    }
}
