package com.ruoyi.sip.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import java.util.ArrayList;
import java.util.Map;
import java.util.stream.Collectors;

import com.ruoyi.common.utils.StringUtils;
import org.springframework.transaction.annotation.Transactional;
import com.ruoyi.sip.domain.OrderList;
import com.ruoyi.sip.mapper.OrderInfoMapper;
import com.ruoyi.sip.domain.OrderInfo;
import com.ruoyi.sip.service.IOrderInfoService;
import com.ruoyi.common.core.text.Convert;

/**
 * 合同档案Service业务层处理
 * 
 * @author mula
 * @date 2025-04-11
 */
@Service
public class OrderInfoServiceImpl implements IOrderInfoService 
{
    @Autowired
    private OrderInfoMapper orderInfoMapper;

    /**
     * 查询合同档案
     * 
     * @param id 合同档案主键
     * @return 合同档案
     */
    @Override
    public OrderInfo selectOrderInfoById(Long id)
    {
        return orderInfoMapper.selectOrderInfoById(id);
    }

    /**
     * 查询合同档案列表
     * 
     * @param orderInfo 合同档案
     * @return 合同档案
     */
    @Override
    public List<OrderInfo> selectOrderInfoList(OrderInfo orderInfo)
    {
        return orderInfoMapper.selectOrderInfoList(orderInfo);
    }

    /**
     * 新增合同档案
     * 
     * @param orderInfo 合同档案
     * @return 结果
     */
    @Transactional
    @Override
    public int insertOrderInfo(OrderInfo orderInfo)
    {
        int rows = orderInfoMapper.insertOrderInfo(orderInfo);
        insertOrderList(orderInfo);
        return rows;
    }

    /**
     * 修改合同档案
     * 
     * @param orderInfo 合同档案
     * @return 结果
     */
    @Transactional
    @Override
    public int updateOrderInfo(OrderInfo orderInfo)
    {
        List<OrderList> orderListList = orderInfo.getOrderListList();
        Map<String, List<OrderList>> operateMap =
                orderListList.stream().collect(Collectors.groupingBy(OrderList::getOperateFlag));
        //新增
        List<OrderList> addList = operateMap.get("0");
        if (addList!=null && !addList.isEmpty()){
            orderInfoMapper.batchOrderList(addList);
        }
        //更新
        List<OrderList> updateList = operateMap.get("1");
        if (updateList!=null && !updateList.isEmpty()){

            orderInfoMapper.updateListBatch(updateList);
        }
        //删除
        List<OrderList> deleteList = operateMap.get("2");
        if (deleteList!=null && !deleteList.isEmpty()){

            orderInfoMapper.logicRemoveListById(deleteList);
        }
        return orderInfoMapper.updateOrderInfo(orderInfo);
    }

    /**
     * 批量删除合同档案
     * 
     * @param ids 需要删除的合同档案主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deleteOrderInfoByIds(String ids)
    {
        orderInfoMapper.deleteOrderListByOrderIds(Convert.toStrArray(ids));
        return orderInfoMapper.deleteOrderInfoByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除合同档案信息
     * 
     * @param id 合同档案主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deleteOrderInfoById(Long id)
    {
        orderInfoMapper.deleteOrderListByOrderId(id);
        return orderInfoMapper.deleteOrderInfoById(id);
    }

    /**
     * 新增合同清单信息
     * 
     * @param orderInfo 合同档案对象
     */
    public void insertOrderList(OrderInfo orderInfo)
    {
        List<OrderList> orderListList = orderInfo.getOrderListList();
        Long id = orderInfo.getId();
        if (StringUtils.isNotNull(orderListList))
        {
            List<OrderList> list = new ArrayList<OrderList>();
            for (OrderList orderList : orderListList)
            {
                orderList.setOrderId(id);
                list.add(orderList);
            }
            if (list.size() > 0)
            {
                orderInfoMapper.batchOrderList(list);
            }
        }
    }
}
